﻿Option Strict On
Imports Microsoft.Kinect
Imports Coding4Fun.Kinect.Wpf
Class MainWindow
    Dim kinect As KinectSensor


    Private Sub MainWindow_Loaded(sender As Object, e As System.Windows.RoutedEventArgs) Handles Me.Loaded
        Try
            If KinectSensor.KinectSensors.Count = 0 Then
                MessageBox.Show("KINECTが接続されておりません。")
                Exit Sub
            Else
                kinect = KinectSensor.KinectSensors(0)
                kinect.ColorStream.Enable(ColorImageFormat.RgbResolution640x480Fps30)
                kinect.SkeletonStream.Enable()
                AddHandler kinect.AllFramesReady, AddressOf kinect_AllFramesReady

                kinect.Start()
            End If
        Catch ex As Exception
            MessageBox.Show(ex.Message)
            Exit Sub
        End Try
    End Sub

    Private Sub kinect_AllFramesReady(sender As Object, e As AllFramesReadyEventArgs)
        Using mySkeletonImage As SkeletonFrame = e.OpenSkeletonFrame
            rgbImage.Source = e.OpenColorImageFrame.ToBitmapSource
            mySkeletonShow(e)
        End Using
    End Sub

    Private Sub mySkeletonShow(e As AllFramesReadyEventArgs)
        skeletonShow.Children.Clear()
        Using mySkeletonFrame As SkeletonFrame = e.OpenSkeletonFrame
            If mySkeletonFrame Is Nothing = False Then
                Dim skeletonData As Skeleton() = New Skeleton(mySkeletonFrame.SkeletonArrayLength - 1) {}
                mySkeletonFrame.CopySkeletonDataTo(skeletonData)

                For Each mySkeleton In skeletonData
                    If mySkeleton.TrackingState = SkeletonTrackingState.Tracked Then
                        For Each myJoint As Joint In mySkeleton.Joints
                            Dim myPoint As ColorImagePoint = kinect.MapSkeletonPointToColor(myJoint.Position, kinect.ColorStream.Format)
                            skeletonShow.Children.Add(New Rectangle() With {.Margin = New Thickness(myPoint.X, myPoint.Y, 0, 0),
                                                                          .Fill = New SolidColorBrush(Colors.Red),
                                                                          .Width = 15, .Height = 15})
                        Next
                    End If
                Next
            End If
        End Using
    End Sub

    Private Sub MainWindow_Closing(sender As Object, e As System.ComponentModel.CancelEventArgs) Handles Me.Closing
        If kinect Is Nothing = False Then
            If kinect.IsRunning = True Then
                RemoveHandler kinect.AllFramesReady, AddressOf kinect_AllFramesReady
                kinect.Stop()
                kinect.Dispose()
            End If
        End If
    End Sub
End Class
